Crate mesh_rasterization

Crate mesh_rasterization 

Functions

blocks_to_mesh
mesh_to_sdf
Takes a closed triangle mesh and returns a signed distance field. The distance field is stored in a 1D array.
mesh_to_sdf_with_known_bounds
Similar to mesh_to_sdf, but takes a bounding box for the mesh.
mesh_to_voxels
Convert a mesh to boolean inclusion voxels. Returns only the coordinates of the voxels that are occupied, the rest are implicitly empty.
rasterize_triangle